# panstamps

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/panstamps)](https://pypi.org/project/panstamps/)  
[![](https://img.shields.io/pypi/v/panstamps)](https://pypi.org/project/panstamps/)  
[![](https://img.shields.io/github/license/thespacedoctor/panstamps)](https://github.com/thespacedoctor/panstamps)  
[![](https://img.shields.io/pypi/dm/panstamps)](https://pypi.org/project/panstamps/)  

<!-- STATUS BADGES -->  

[![](http://157.245.42.153:8080/buildStatus/icon?job=panstamps%2Fmaster&subject=build%20master)](http://157.245.42.153:8080/blue/organizations/jenkins/panstamps/activity?branch=master)  
[![](http://157.245.42.153:8080/buildStatus/icon?job=panstamps%2Fdevelop&subject=build%20dev)](http://157.245.42.153:8080/blue/organizations/jenkins/panstamps/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/panstamps@master/coverage.svg)](https://raw.githack.com/thespacedoctor/panstamps/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/panstamps/badge/?version=master)](https://panstamps.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/panstamps/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/panstamps/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*Download stacked and/or warp image stamps from the STScI PanSTARRS image server via CL or Python API*.

Documentation for panstamps is hosted by [Read the Docs](https://panstamps.readthedocs.io/en/master/) (
[development version](https://panstamps.readthedocs.io/en/develop/) and [master version](https://panstamps.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/panstamps). Please report any issues you find [here](https://github.com/thespacedoctor/panstamps/issues).

```eval_rst
.. note::
    If working with warped PS1 images then you need to work off a machine that has an IP address whitelisted by the `Pan-STARRS1 data archive <https://panstarrs.stsci.edu/>`_, otherwise only stacked images will be available to you. Also *w*-band images are not (yet) accessible from the data archive.
```

## Features

* 
